==> vst3sdk-docs-3.7.8_build_34-2-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstsdk/hierarchy.js <==
var hierarchy =
[
    [ "AudioBuffer< T >", "classSteinberg_1_1Vst_1_1AudioBuffer.html", null ],
    [ "BypassProcessor< T >", "classSteinberg_1_1Vst_1_1BypassProcessor.html", null ],
    [ "CBaseObject", null, [
      [ "VSTGUIEditor", "classSteinberg_1_1Vst_1_1VSTGUIEditor.html", null ]
    ] ],
    [ "ClassInfo", "classVST3_1_1Hosting_1_1ClassInfo.html", null ],
    [ "ClassInfo::Data", "structVST3_1_1Hosting_1_1ClassInfo_1_1Data.html", null ],
    [ "BypassProcessor< T >::Delay", "structSteinberg_1_1Vst_1_1BypassProcessor_1_1Delay.html", null ],
    [ "PresetFile::Entry", "structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html", null ],
    [ "FactoryInfo", "classVST3_1_1Hosting_1_1FactoryInfo.html", null ],
    [ "FObject", null, [
      [ "CPluginView", "classSteinberg_1_1CPluginView.html", [
        [ "EditorView", "classSteinberg_1_1Vst_1_1EditorView.html", [
          [ "VSTGUIEditor", "classSteinberg_1_1Vst_1_1VSTGUIEditor.html", null ]
        ] ]
      ] ],
      [ "Bus", "classSteinberg_1_1Vst_1_1Bus.html", [
        [ "AudioBus", "classSteinberg_1_1Vst_1_1AudioBus.html", null ],
        [ "EventBus", "classSteinberg_1_1Vst_1_1EventBus.html", null ]
      ] ],
      [ "BusList", "classSteinberg_1_1Vst_1_1BusList.html", null ],
      [ "ComponentBase", "classSteinberg_1_1Vst_1_1ComponentBase.html", [
        [ "Component", "classSteinberg_1_1Vst_1_1Component.html", [
          [ "AudioEffect", "classSteinberg_1_1Vst_1_1AudioEffect.html", null ]
        ] ],
        [ "EditController", "classSteinberg_1_1Vst_1_1EditController.html", [
          [ "EditControllerEx1", "classSteinberg_1_1Vst_1_1EditControllerEx1.html", [
            [ "SingleComponentEffect", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html", null ]
          ] ]
        ] ]
      ] ],
      [ "PresetManager", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html", null ],
      [ "NoteExpressionType", "classSteinberg_1_1Vst_1_1NoteExpressionType.html", [
        [ "RangeNoteExpressionType", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html", null ]
      ] ],
      [ "NoteExpressionTypeContainer", "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html", null ],
      [ "Parameter", "classSteinberg_1_1Vst_1_1Parameter.html", [
        [ "RangeParameter", "classSteinberg_1_1Vst_1_1RangeParameter.html", null ],
        [ "StringListParameter", "classSteinberg_1_1Vst_1_1StringListParameter.html", null ]
      ] ],
      [ "PlugProvider", "classSteinberg_1_1Vst_1_1PlugProvider.html", null ],
      [ "ProgramList", "classSteinberg_1_1Vst_1_1ProgramList.html", [
        [ "ProgramListWithPitchNames", "classSteinberg_1_1Vst_1_1ProgramListWithPitchNames.html", null ]
      ] ],
      [ "Unit", "classSteinberg_1_1Vst_1_1Unit.html", null ]
    ] ],
    [ "FUnknown", "../base/classSteinberg_1_1FUnknown.html", [
      [ "IBStream", "../base/classSteinberg_1_1IBStream.html", [
        [ "MemoryStream", "classSteinberg_1_1MemoryStream.html", null ],
        [ "BufferStream", "classSteinberg_1_1Vst_1_1BufferStream.html", null ],
        [ "FileStream", "classSteinberg_1_1Vst_1_1FileStream.html", null ],
        [ "ReadOnlyBStream", "classSteinberg_1_1Vst_1_1ReadOnlyBStream.html", null ]
      ] ],
      [ "IPluginBase", "../base/classSteinberg_1_1IPluginBase.html", [
        [ "ComponentBase", "classSteinberg_1_1Vst_1_1ComponentBase.html", null ],
        [ "IComponent", "../vstinterfaces/classSteinberg_1_1Vst_1_1IComponent.html", [
          [ "Component", "classSteinberg_1_1Vst_1_1Component.html", null ],
          [ "SingleComponentEffect", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html", null ]
        ] ],
        [ "IEditController", "../vstinterfaces/classSteinberg_1_1Vst_1_1IEditController.html", [
          [ "EditController", "classSteinberg_1_1Vst_1_1EditController.html", null ]
        ] ]
      ] ],
      [ "IPlugView", "../base/classSteinberg_1_1IPlugView.html", [
        [ "CPluginView", "classSteinberg_1_1CPluginView.html", null ]
      ] ],
      [ "IStringResult", "../base/classSteinberg_1_1IStringResult.html", [
        [ "StringResult", "exceptionSteinberg_1_1Vst_1_1StringResult.html", null ]
      ] ],
      [ "ITest", "../vstinterfaces/classSteinberg_1_1ITest.html", [
        [ "TestBase", "classSteinberg_1_1Vst_1_1TestBase.html", [
          [ "TestEnh", "classSteinberg_1_1Vst_1_1TestEnh.html", null ]
        ] ]
      ] ],
      [ "IAttributeList", "../vstinterfaces/classSteinberg_1_1Vst_1_1IAttributeList.html", [
        [ "HostAttributeList", "exceptionSteinberg_1_1Vst_1_1HostAttributeList.html", null ]
      ] ],
      [ "IAudioProcessor", "../vstinterfaces/classSteinberg_1_1Vst_1_1IAudioProcessor.html", [
        [ "AudioEffect", "classSteinberg_1_1Vst_1_1AudioEffect.html", null ],
        [ "SingleComponentEffect", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html", null ]
      ] ],
      [ "IConnectionPoint", "../vstinterfaces/classSteinberg_1_1Vst_1_1IConnectionPoint.html", [
        [ "ComponentBase", "classSteinberg_1_1Vst_1_1ComponentBase.html", null ],
        [ "ConnectionProxy", "classSteinberg_1_1Vst_1_1ConnectionProxy.html", null ]
      ] ],
      [ "IEditController2", "../vstinterfaces/classSteinberg_1_1Vst_1_1IEditController2.html", [
        [ "EditController", "classSteinberg_1_1Vst_1_1EditController.html", null ]
      ] ],
      [ "IEventList", "../vstinterfaces/classSteinberg_1_1Vst_1_1IEventList.html", [
        [ "EventList", "classSteinberg_1_1Vst_1_1EventList.html", null ]
      ] ],
      [ "IHostApplication", "../vstinterfaces/classSteinberg_1_1Vst_1_1IHostApplication.html", [
        [ "HostApplication", "classSteinberg_1_1Vst_1_1HostApplication.html", null ]
      ] ],
      [ "IInterAppAudioPresetManager", "../vstinterfaces/classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html", [
        [ "PresetManager", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html", null ]
      ] ],
      [ "IMessage", "../vstinterfaces/classSteinberg_1_1Vst_1_1IMessage.html", [
        [ "HostMessage", "exceptionSteinberg_1_1Vst_1_1HostMessage.html", null ]
      ] ],
      [ "IParameterChanges", "../vstinterfaces/classSteinberg_1_1Vst_1_1IParameterChanges.html", [
        [ "ParameterChanges", "classSteinberg_1_1Vst_1_1ParameterChanges.html", null ]
      ] ],
      [ "IParamValueQueue", "../vstinterfaces/classSteinberg_1_1Vst_1_1IParamValueQueue.html", [
        [ "ParamChanges", "classSteinberg_1_1Vst_1_1ParamChanges.html", null ],
        [ "ParameterValueQueue", "classSteinberg_1_1Vst_1_1ParameterValueQueue.html", null ]
      ] ],
      [ "IPlugInterfaceSupport", "../vstinterfaces/classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html", [
        [ "PlugInterfaceSupport", "classSteinberg_1_1Vst_1_1PlugInterfaceSupport.html", null ]
      ] ],
      [ "IProcessContextRequirements", "../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html", [
        [ "AudioEffect", "classSteinberg_1_1Vst_1_1AudioEffect.html", null ],
        [ "SingleComponentEffect", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html", null ]
      ] ],
      [ "ITestPlugProvider", "../vstinterfaces/classSteinberg_1_1Vst_1_1ITestPlugProvider.html", [
        [ "ITestPlugProvider2", "../vstinterfaces/classSteinberg_1_1Vst_1_1ITestPlugProvider2.html", [
          [ "PlugProvider", "classSteinberg_1_1Vst_1_1PlugProvider.html", null ]
        ] ]
      ] ],
      [ "IUnitInfo", "../vstinterfaces/classSteinberg_1_1Vst_1_1IUnitInfo.html", [
        [ "EditControllerEx1", "classSteinberg_1_1Vst_1_1EditControllerEx1.html", null ]
      ] ]
    ] ],
    [ "Handler", "structSteinberg_1_1Vst_1_1MPE_1_1Handler.html", null ],
    [ "Module::Snapshot::ImageDesc", "structVST3_1_1Hosting_1_1Module_1_1Snapshot_1_1ImageDesc.html", null ],
    [ "MidiIO", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html", null ],
    [ "Module", "classVST3_1_1Hosting_1_1Module.html", null ],
    [ "ObjCClassBuilder", "structSteinberg_1_1ObjCClassBuilder.html", null ],
    [ "ObjCInstance", "structSteinberg_1_1ObjCInstance.html", null ],
    [ "ObjCVariable< T >", "structSteinberg_1_1ObjCVariable.html", null ],
    [ "Optional< T >", "structVST3_1_1Optional.html", null ],
    [ "Parameter", "structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html", null ],
    [ "ParameterChangeTransfer::ParameterChange", "structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html", null ],
    [ "ParameterChangeTransfer", "classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html", null ],
    [ "ParameterContainer", "classSteinberg_1_1Vst_1_1ParameterContainer.html", null ],
    [ "ParameterValueQueue::ParameterQueueValue", "structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue.html", null ],
    [ "ParamPoint", "classSteinberg_1_1Vst_1_1ParamPoint.html", null ],
    [ "PluginContextFactory", "classSteinberg_1_1Vst_1_1PluginContextFactory.html", null ],
    [ "PluginFactory", "classVST3_1_1Hosting_1_1PluginFactory.html", null ],
    [ "PresetFile", "classSteinberg_1_1Vst_1_1PresetFile.html", null ],
    [ "ProcessContextRequirements", "classSteinberg_1_1Vst_1_1ProcessContextRequirements.html", null ],
    [ "ProcessData", "../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessData.html", [
      [ "HostProcessData", "classSteinberg_1_1Vst_1_1HostProcessData.html", null ]
    ] ],
    [ "ProcessDataSlicer", "classSteinberg_1_1Vst_1_1ProcessDataSlicer.html", null ],
    [ "Processor", "classSteinberg_1_1Vst_1_1MPE_1_1Processor.html", null ],
    [ "RingBuffer< ItemT >", "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html", null ],
    [ "RTTransferT< ObjectT, Deleter >", "structSteinberg_1_1Vst_1_1RTTransferT.html", null ],
    [ "Setup", "structSteinberg_1_1Vst_1_1MPE_1_1Setup.html", null ],
    [ "Module::Snapshot", "structVST3_1_1Hosting_1_1Module_1_1Snapshot.html", null ],
    [ "SpeakerArray", "classSteinberg_1_1Vst_1_1SpeakerArray.html", null ],
    [ "TestDefaults", "structSteinberg_1_1Vst_1_1TestDefaults.html", null ],
    [ "TestingPluginContext", "structSteinberg_1_1Vst_1_1TestingPluginContext.html", null ],
    [ "<UIApplicationDelegate>", null, [
      [ "VSTInterAppAudioAppDelegateBase", "interfaceVSTInterAppAudioAppDelegateBase.html", null ]
    ] ],
    [ "UID", "structVST3_1_1UID.html", null ],
    [ "<UIResponder>", null, [
      [ "VSTInterAppAudioAppDelegateBase", "interfaceVSTInterAppAudioAppDelegateBase.html", null ]
    ] ],
    [ "vector", null, [
      [ "BusList", "classSteinberg_1_1Vst_1_1BusList.html", null ]
    ] ],
    [ "Version", "structVST3_1_1Version.html", null ],
    [ "Vst2xProgram", "structVST3_1_1Vst2xProgram.html", null ],
    [ "Vst2xState", "structVST3_1_1Vst2xState.html", null ],
    [ "VSTGUIEditorInterface", null, [
      [ "VSTGUIEditor", "classSteinberg_1_1Vst_1_1VSTGUIEditor.html", null ]
    ] ],
    [ "XmlRepresentationHelper", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html", null ]
];

==> vst3sdk-docs-3.7.9_build_61-1-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstsdk/hierarchy.js <==
var hierarchy =
[
    [ "AudioBuffer< T >", "classSteinberg_1_1Vst_1_1AudioBuffer.html", null ],
    [ "BypassProcessor< T >", "classSteinberg_1_1Vst_1_1BypassProcessor.html", null ],
    [ "CBaseObject", null, [
      [ "VSTGUIEditor", "classSteinberg_1_1Vst_1_1VSTGUIEditor.html", null ]
    ] ],
    [ "ClassInfo", "classVST3_1_1Hosting_1_1ClassInfo.html", null ],
    [ "DataExchangeHandler::Config", "structSteinberg_1_1Vst_1_1DataExchangeHandler_1_1Config.html", null ],
    [ "ClassInfo::Data", "structVST3_1_1Hosting_1_1ClassInfo_1_1Data.html", null ],
    [ "DataExchangeHandler", "classSteinberg_1_1Vst_1_1DataExchangeHandler.html", null ],
    [ "DataExchangeReceiverHandler", "classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html", null ],
    [ "BypassProcessor< T >::Delay", "structSteinberg_1_1Vst_1_1BypassProcessor_1_1Delay.html", null ],
    [ "PresetFile::Entry", "structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html", null ],
    [ "FactoryInfo", "classVST3_1_1Hosting_1_1FactoryInfo.html", null ],
    [ "FObject", null, [
      [ "CPluginView", "classSteinberg_1_1CPluginView.html", [
        [ "EditorView", "classSteinberg_1_1Vst_1_1EditorView.html", [
          [ "VSTGUIEditor", "classSteinberg_1_1Vst_1_1VSTGUIEditor.html", null ]
        ] ]
      ] ],
      [ "Bus", "classSteinberg_1_1Vst_1_1Bus.html", [
        [ "AudioBus", "classSteinberg_1_1Vst_1_1AudioBus.html", null ],
        [ "EventBus", "classSteinberg_1_1Vst_1_1EventBus.html", null ]
      ] ],
      [ "BusList", "classSteinberg_1_1Vst_1_1BusList.html", null ],
      [ "ComponentBase", "classSteinberg_1_1Vst_1_1ComponentBase.html", [
        [ "Component", "classSteinberg_1_1Vst_1_1Component.html", [
          [ "AudioEffect", "classSteinberg_1_1Vst_1_1AudioEffect.html", null ]
        ] ],
        [ "EditController", "classSteinberg_1_1Vst_1_1EditController.html", [
          [ "EditControllerEx1", "classSteinberg_1_1Vst_1_1EditControllerEx1.html", [
            [ "SingleComponentEffect", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html", null ]
          ] ]
        ] ]
      ] ],
      [ "PresetManager", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html", null ],
      [ "NoteExpressionType", "classSteinberg_1_1Vst_1_1NoteExpressionType.html", [
        [ "RangeNoteExpressionType", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html", null ]
      ] ],
      [ "NoteExpressionTypeContainer", "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html", null ],
      [ "Parameter", "classSteinberg_1_1Vst_1_1Parameter.html", [
        [ "RangeParameter", "classSteinberg_1_1Vst_1_1RangeParameter.html", null ],
        [ "StringListParameter", "classSteinberg_1_1Vst_1_1StringListParameter.html", null ]
      ] ],
      [ "ProgramList", "classSteinberg_1_1Vst_1_1ProgramList.html", [
        [ "ProgramListWithPitchNames", "classSteinberg_1_1Vst_1_1ProgramListWithPitchNames.html", null ]
      ] ],
      [ "Unit", "classSteinberg_1_1Vst_1_1Unit.html", null ]
    ] ],
    [ "FUnknown", "../base/classSteinberg_1_1FUnknown.html", [
      [ "IBStream", "../base/classSteinberg_1_1IBStream.html", [
        [ "MemoryStream", "classSteinberg_1_1MemoryStream.html", null ],
        [ "BufferStream", "classSteinberg_1_1Vst_1_1BufferStream.html", null ],
        [ "FileStream", "classSteinberg_1_1Vst_1_1FileStream.html", null ],
        [ "ReadOnlyBStream", "classSteinberg_1_1Vst_1_1ReadOnlyBStream.html", null ]
      ] ],
      [ "IPluginBase", "../base/classSteinberg_1_1IPluginBase.html", [
        [ "ComponentBase", "classSteinberg_1_1Vst_1_1ComponentBase.html", null ],
        [ "IComponent", "../vstinterfaces/classSteinberg_1_1Vst_1_1IComponent.html", [
          [ "Component", "classSteinberg_1_1Vst_1_1Component.html", null ],
          [ "SingleComponentEffect", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html", null ]
        ] ],
        [ "IEditController", "../vstinterfaces/classSteinberg_1_1Vst_1_1IEditController.html", [
          [ "EditController", "classSteinberg_1_1Vst_1_1EditController.html", null ]
        ] ]
      ] ],
      [ "IPlugView", "../base/classSteinberg_1_1IPlugView.html", [
        [ "CPluginView", "classSteinberg_1_1CPluginView.html", null ]
      ] ],
      [ "IStringResult", "../base/classSteinberg_1_1IStringResult.html", [
        [ "StringResult", "exceptionSteinberg_1_1Vst_1_1StringResult.html", null ]
      ] ],
      [ "ITest", "../vstinterfaces/classSteinberg_1_1ITest.html", [
        [ "TestBase", "classSteinberg_1_1Vst_1_1TestBase.html", [
          [ "TestEnh", "classSteinberg_1_1Vst_1_1TestEnh.html", null ]
        ] ]
      ] ],
      [ "IAttributeList", "../vstinterfaces/classSteinberg_1_1Vst_1_1IAttributeList.html", [
        [ "HostAttributeList", "exceptionSteinberg_1_1Vst_1_1HostAttributeList.html", null ]
      ] ],
      [ "IAudioProcessor", "../vstinterfaces/classSteinberg_1_1Vst_1_1IAudioProcessor.html", [
        [ "AudioEffect", "classSteinberg_1_1Vst_1_1AudioEffect.html", null ],
        [ "SingleComponentEffect", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html", null ]
      ] ],
      [ "IConnectionPoint", "../vstinterfaces/classSteinberg_1_1Vst_1_1IConnectionPoint.html", [
        [ "ComponentBase", "classSteinberg_1_1Vst_1_1ComponentBase.html", null ],
        [ "ConnectionProxy", "classSteinberg_1_1Vst_1_1ConnectionProxy.html", null ]
      ] ],
      [ "IEditController2", "../vstinterfaces/classSteinberg_1_1Vst_1_1IEditController2.html", [
        [ "EditController", "classSteinberg_1_1Vst_1_1EditController.html", null ]
      ] ],
      [ "IEventList", "../vstinterfaces/classSteinberg_1_1Vst_1_1IEventList.html", [
        [ "EventList", "classSteinberg_1_1Vst_1_1EventList.html", null ]
      ] ],
      [ "IHostApplication", "../vstinterfaces/classSteinberg_1_1Vst_1_1IHostApplication.html", [
        [ "HostApplication", "classSteinberg_1_1Vst_1_1HostApplication.html", null ]
      ] ],
      [ "IInterAppAudioPresetManager", "../vstinterfaces/classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html", [
        [ "PresetManager", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html", null ]
      ] ],
      [ "IMessage", "../vstinterfaces/classSteinberg_1_1Vst_1_1IMessage.html", [
        [ "HostMessage", "exceptionSteinberg_1_1Vst_1_1HostMessage.html", null ]
      ] ],
      [ "IParameterChanges", "../vstinterfaces/classSteinberg_1_1Vst_1_1IParameterChanges.html", [
        [ "ParameterChanges", "classSteinberg_1_1Vst_1_1ParameterChanges.html", null ]
      ] ],
      [ "IParamValueQueue", "../vstinterfaces/classSteinberg_1_1Vst_1_1IParamValueQueue.html", [
        [ "ParamChanges", "classSteinberg_1_1Vst_1_1ParamChanges.html", null ],
        [ "ParameterValueQueue", "classSteinberg_1_1Vst_1_1ParameterValueQueue.html", null ]
      ] ],
      [ "IPlugInterfaceSupport", "../vstinterfaces/classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html", [
        [ "PlugInterfaceSupport", "classSteinberg_1_1Vst_1_1PlugInterfaceSupport.html", null ]
      ] ],
      [ "IProcessContextRequirements", "../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html", [
        [ "AudioEffect", "classSteinberg_1_1Vst_1_1AudioEffect.html", null ],
        [ "SingleComponentEffect", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html", null ]
      ] ],
      [ "IUnitInfo", "../vstinterfaces/classSteinberg_1_1Vst_1_1IUnitInfo.html", [
        [ "EditControllerEx1", "classSteinberg_1_1Vst_1_1EditControllerEx1.html", null ]
      ] ]
    ] ],
    [ "Handler", "structSteinberg_1_1Vst_1_1MPE_1_1Handler.html", null ],
    [ "HostDataExchangeHandler", "structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html", null ],
    [ "IDataExchangeHandlerHost", "structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html", null ],
    [ "Module::Snapshot::ImageDesc", "structVST3_1_1Hosting_1_1Module_1_1Snapshot_1_1ImageDesc.html", null ],
    [ "Implements", null, [
      [ "PlugProvider", "classSteinberg_1_1Vst_1_1PlugProvider.html", null ]
    ] ],
    [ "MidiIO", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html", null ],
    [ "Module", "classVST3_1_1Hosting_1_1Module.html", null ],
    [ "ObjCClassBuilder", "structSteinberg_1_1ObjCClassBuilder.html", null ],
    [ "ObjCInstance", "structSteinberg_1_1ObjCInstance.html", null ],
    [ "ObjCVariable< T >", "structSteinberg_1_1ObjCVariable.html", null ],
    [ "Optional< T >", "structVST3_1_1Optional.html", null ],
    [ "Parameter", "structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html", null ],
    [ "ParameterChangeTransfer::ParameterChange", "structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html", null ],
    [ "ParameterChangeTransfer", "classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html", null ],
    [ "ParameterContainer", "classSteinberg_1_1Vst_1_1ParameterContainer.html", null ],
    [ "ParameterValueQueue::ParameterQueueValue", "structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue.html", null ],
    [ "ParamPoint", "classSteinberg_1_1Vst_1_1ParamPoint.html", null ],
    [ "PluginContextFactory", "classSteinberg_1_1Vst_1_1PluginContextFactory.html", null ],
    [ "PluginFactory", "classVST3_1_1Hosting_1_1PluginFactory.html", null ],
    [ "PresetFile", "classSteinberg_1_1Vst_1_1PresetFile.html", null ],
    [ "ProcessContextRequirements", "classSteinberg_1_1Vst_1_1ProcessContextRequirements.html", null ],
    [ "ProcessData", "../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessData.html", [
      [ "HostProcessData", "classSteinberg_1_1Vst_1_1HostProcessData.html", null ]
    ] ],
    [ "ProcessDataSlicer", "classSteinberg_1_1Vst_1_1ProcessDataSlicer.html", null ],
    [ "Processor", "classSteinberg_1_1Vst_1_1MPE_1_1Processor.html", null ],
    [ "RingBuffer< ItemT >", "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html", null ],
    [ "RingBuffer< Block >", "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html", null ],
    [ "RingBuffer< void * >", "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html", null ],
    [ "RTTransferT< ObjectT, Deleter >", "structSteinberg_1_1Vst_1_1RTTransferT.html", null ],
    [ "Setup", "structSteinberg_1_1Vst_1_1MPE_1_1Setup.html", null ],
    [ "Module::Snapshot", "structVST3_1_1Hosting_1_1Module_1_1Snapshot.html", null ],
    [ "SpeakerArray", "classSteinberg_1_1Vst_1_1SpeakerArray.html", null ],
    [ "SystemTime", "classSteinberg_1_1Vst_1_1SystemTime.html", null ],
    [ "TestDefaults", "structSteinberg_1_1Vst_1_1TestDefaults.html", null ],
    [ "TestingPluginContext", "structSteinberg_1_1Vst_1_1TestingPluginContext.html", null ],
    [ "<UIApplicationDelegate>", null, [
      [ "VSTInterAppAudioAppDelegateBase", "interfaceVSTInterAppAudioAppDelegateBase.html", null ]
    ] ],
    [ "UID", "structVST3_1_1UID.html", null ],
    [ "<UIResponder>", null, [
      [ "VSTInterAppAudioAppDelegateBase", "interfaceVSTInterAppAudioAppDelegateBase.html", null ]
    ] ],
    [ "vector", null, [
      [ "BusList", "classSteinberg_1_1Vst_1_1BusList.html", null ]
    ] ],
    [ "Version", "structVST3_1_1Version.html", null ],
    [ "Vst2xProgram", "structVST3_1_1Vst2xProgram.html", null ],
    [ "Vst2xState", "structVST3_1_1Vst2xState.html", null ],
    [ "VSTGUIEditorInterface", null, [
      [ "VSTGUIEditor", "classSteinberg_1_1Vst_1_1VSTGUIEditor.html", null ]
    ] ],
    [ "XmlRepresentationHelper", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html", null ]
];
